@@ -15,7 +15,12 @@ Authors = ["Christian Schaller <uraeus@gnome.org>",
            "Tom Parker <palfrey@tevp.neta>",
            "Arun Raghavan <arunsr@gnome.org>",
            "Laszlo Pandy <laszlok2@gmail.com>",
-           "Claude Paroz <claude@2xlibre.net>"
+           "Claude Paroz <claude@2xlibre.net>",
+           "Javier Jardón <jjardon@gnome.org>",
+           "Frederik Elwert <frederik.elwert@web.de>",
+           "Marek Černocký <marek@manet.cz>",
+           "Szilveszter Ördög <slipszi@gmail.com>",
+           "Richard Hughes <richard@hughsie.com>"
            ]
 
 Artists = ["Jakub Steiner <jimmac@gnome.org>"]
@@ -40,7 +45,7 @@ License along with this library; if not, see <http://www.gnu.org/licenses/>.
 class AboutDialog:
    def __init__(self):
        x = Gtk.AboutDialog()
-       x.set_version("1.3")
+       x.set_version("1.4")
        x.set_name(_("Transmageddon"))
        x.set_program_name(_("Transmageddon"))
        x.set_website("http://www.linuxrising.org")
